/**
 * Copyright 2010 Västra Götalandsregionen
 *
 *   This library is free software; you can redistribute it and/or modify
 *   it under the terms of version 2.1 of the GNU Lesser General Public
 *   License as published by the Free Software Foundation.
 *
 *   This library is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU Lesser General Public License for more details.
 *
 *   You should have received a copy of the GNU Lesser General Public
 *   License along with this library; if not, write to the
 *   Free Software Foundation, Inc., 59 Temple Place, Suite 330,
 *   Boston, MA 02111-1307  USA
 */

package se.vgregion.alfrescoclient.controller;

/**
 * 
 */
import static javax.portlet.PortletRequest.USER_INFO;
import static javax.portlet.PortletRequest.P3PUserInfos.USER_LOGIN_ID;

import java.util.Map;

import javax.portlet.PortletPreferences;
import javax.portlet.PortletRequest;
import javax.portlet.RenderRequest;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.portlet.bind.annotation.RenderMapping;

import se.vgregion.alfrescoclient.service.AlfrescoService;

/**
 * The controller for the alfresco sites portlet.
 * 
 * @author Simon Göransson
 * @author Björn Ryding
 * 
 */

@Controller
@RequestMapping(value = "VIEW")
public class SitesController {

    @Autowired
    private AlfrescoService alfrescoService;

    /**
     * Renders the Alfresco site list view.
     * 
     * @param model
     *            the model
     * @param request
     *            the request
     * @return the view to render
     */
    @RenderMapping
    public String viewSites(Model model, RenderRequest request) {

        PortletPreferences prefs = request.getPreferences();

        String csIframPage = prefs.getValue("csIframePage", "");
        String portletInstance = prefs.getValue("portalInstance", "");

        String userId = lookupUid(request);
        if (userId != "") {
            model.addAttribute("userSites",
                    alfrescoService.getSitesByUser(userId, csIframPage, portletInstance));
            model.addAttribute("publicSites",
                    alfrescoService.getPublicSites(userId, csIframPage, portletInstance));
            return "view";
        }

        return "notloggedin";
    }

    /**
     * Retrieves the user id for the logged in user.
     * 
     * @param req
     *            the portlet request
     * @return the user id
     */
    @SuppressWarnings("unchecked")
    private String lookupUid(PortletRequest req) {
        Map<String, ?> userInfo = (Map<String, ?>) req.getAttribute(USER_INFO);
        String userId = "";
        if (userInfo != null && userInfo.get(USER_LOGIN_ID.toString()) != null) {
            userId = (String) userInfo.get(USER_LOGIN_ID.toString());
        }
        return userId;
    }

}
